@@ -1,24 +1,23 @@
-/*  $Id: internal.h 2679 2006-08-09 15:45:17Z rra $
+/*  $Id: internal.h 2978 2007-02-11 03:37:08Z rra $
 **
 **  Internal support functions for the remctl client library.
 **
 **  Written by Russ Allbery <rra@stanford.edu>
 **  Based on prior work by Anton Ushakov <antonu@stanford.edu>
+**  Copyright 2002, 2003, 2004, 2005, 2006, 2007
+**      Board of Trustees, Leland Stanford Jr. University
+**
+**  See README for licensing terms.
 */
 
 #ifndef CLIENT_INTERNAL_H
 #define CLIENT_INTERNAL_H 1
 
 #include <config.h>
+#include <portable/gssapi.h>
 
 #include <sys/uio.h>
 
-#ifdef HAVE_GSSAPI_H
-# include <gssapi.h>
-#else
-# include <gssapi/gssapi_generic.h>
-#endif
-
 /* BEGIN_DECLS is used at the beginning of declarations so that C++
    compilers don't mangle their names.  END_DECLS is used at the end. */
 #undef BEGIN_DECLS
