@@ -1,4 +1,4 @@
-/*  $Id: open.c 2978 2007-02-11 03:37:08Z rra $
+/*  $Id: open.c 3646 2007-11-09 07:28:42Z rra $
 **
 **  Open a connection to a remote server.
 **
@@ -28,24 +28,16 @@
 
 
 /*
-**  Open a new connection to a server.  Returns true on success, false on
-**  failure.  On failure, sets the error message appropriately.
+**  Given the remctl object (for error reporting), host, and port, attempt a
+**  network connection.  Returns the file descriptor if successful or -1 on
+**  failure.
 */
-int
-internal_open(struct remctl *r, const char *host, unsigned short port,
-              const char *principal)
+static int
+internal_connect(struct remctl *r, const char *host, unsigned short port)
 {
     struct addrinfo hints, *ai;
     char portbuf[16];
-    int fd, status, flags;
-    gss_buffer_desc send_tok, recv_tok, name_buffer, *token_ptr;
-    gss_buffer_desc empty_token = { 0, (void *) "" };
-    gss_name_t name;
-    gss_ctx_id_t gss_context;
-    OM_uint32 major, minor, init_minor, gss_flags;
-    static const OM_uint32 req_gss_flags
-        = (GSS_C_MUTUAL_FLAG | GSS_C_REPLAY_FLAG | GSS_C_CONF_FLAG
-           | GSS_C_INTEG_FLAG);
+    int status, fd;
 
     /* Look up the remote host and open a TCP connection.  Call getaddrinfo
        and network_connect instead of network_connect_host so that we can
@@ -58,15 +50,60 @@ internal_open(struct remctl *r, const char *host, unsigned short port,
     if (status != 0) {
         internal_set_error(r, "unknown host %s: %s", host,
                            gai_strerror(status));
-        return 0;
+        return -1;
     }
     fd = network_connect(ai, NULL);
     freeaddrinfo(ai);
     if (fd < 0) {
         internal_set_error(r, "cannot connect to %s (port %hu): %s", host,
                            port, strerror(errno));
-        return 0;
+        return -1;
     }
+    return fd;
+}
+
+
+/*
+**  Open a new connection to a server.  Returns true on success, false on
+**  failure.  On failure, sets the error message appropriately.
+*/
+int
+internal_open(struct remctl *r, const char *host, unsigned short port,
+              const char *principal)
+{
+    char *defprinc = NULL;
+    int status, flags;
+    int port_fallback = 0;
+    int fd = -1;
+    gss_buffer_desc send_tok, recv_tok, name_buffer, *token_ptr;
+    gss_buffer_desc empty_token = { 0, (void *) "" };
+    gss_name_t name = GSS_C_NO_NAME;
+    gss_ctx_id_t gss_context = GSS_C_NO_CONTEXT;
+    OM_uint32 major, minor, init_minor, gss_flags;
+    static const OM_uint32 wanted_gss_flags
+        = (GSS_C_MUTUAL_FLAG | GSS_C_CONF_FLAG | GSS_C_INTEG_FLAG
+           | GSS_C_REPLAY_FLAG | GSS_C_SEQUENCE_FLAG);
+    static const OM_uint32 req_gss_flags
+        = (GSS_C_MUTUAL_FLAG | GSS_C_CONF_FLAG | GSS_C_INTEG_FLAG);
+
+    /* If port is 0, default to trying the standard port and then falling back
+       on the old port.  If principal is NULL, use host/<host> in the default
+       realm. */
+    if (port == 0) {
+        port = REMCTL_PORT;
+        port_fallback = 1;
+    }
+    if (principal == NULL) {
+        defprinc = concat("host/", host, (char *) 0);
+        principal = defprinc;
+    }
+
+    /* Make the network connection. */
+    fd = internal_connect(r, host, port);
+    if (fd < 0 && port_fallback)
+        fd = internal_connect(r, host, REMCTL_PORT_OLD);
+    if (fd < 0)
+        goto fail;
     r->fd = fd;
 
     /* Import the name into target_name. */
@@ -75,9 +112,7 @@ internal_open(struct remctl *r, const char *host, unsigned short port,
     major = gss_import_name(&minor, &name_buffer, GSS_C_NT_USER_NAME, &name);
     if (major != GSS_S_COMPLETE) {
         internal_gssapi_error(r, "parsing name", major, minor);
-        close(fd);
-        r->fd = -1;
-        return 0;
+        goto fail;
     }
 
     /* Default to protocol version two, but if some other protocol is already
@@ -111,11 +146,10 @@ internal_open(struct remctl *r, const char *host, unsigned short port,
        the server ever drops TOKEN_PROTOCOL from the response, we fall back to
        v1. */
     token_ptr = GSS_C_NO_BUFFER;
-    gss_context = GSS_C_NO_CONTEXT;
     do {
         major = gss_init_sec_context(&init_minor, GSS_C_NO_CREDENTIAL, 
                     &gss_context, name, (const gss_OID) GSS_KRB5_MECHANISM,
-                    req_gss_flags, 0, NULL, token_ptr, NULL, &send_tok,
+                    wanted_gss_flags, 0, NULL, token_ptr, NULL, &send_tok,
                     &gss_flags, NULL);
 
         if (token_ptr != GSS_C_NO_BUFFER)
@@ -145,7 +179,7 @@ internal_open(struct remctl *r, const char *host, unsigned short port,
         /* If the flags we get back from the server are bad and we're doing
            protocol v2, report an error and abort. */
         if (r->protocol > 1 && (gss_flags & req_gss_flags) != req_gss_flags) {
-            internal_set_error(r, "server did not negotiate appropriate"
+            internal_set_error(r, "server did not negotiate acceptable"
                                " GSS-API flags");
             goto fail;
         }
@@ -170,10 +204,14 @@ internal_open(struct remctl *r, const char *host, unsigned short port,
     return 1;
 
 fail:
-    close(fd);
+    if (defprinc != NULL)
+        free(defprinc);
+    if (fd >= 0)
+        close(fd);
     r->fd = -1;
-    gss_release_name(&minor, &name);
+    if (name != GSS_C_NO_NAME)
+        gss_release_name(&minor, &name);
     if (gss_context != GSS_C_NO_CONTEXT)
-        gss_delete_sec_context(&minor, gss_context, GSS_C_NO_BUFFER);
+        gss_delete_sec_context(&minor, &gss_context, GSS_C_NO_BUFFER);
     return 0;
 }
