@@ -1,4 +1,4 @@
-/*  $Id: remctl.c 3014 2007-03-06 06:06:30Z rra $
+/*  $Id: remctl.c 3527 2007-09-02 06:31:04Z rra $
 **
 **  The client for a service for remote execution of predefined commands.
 **  Access is authenticated via GSS-API Kerberos 5, authorized via ACL files.
@@ -27,7 +27,7 @@ Usage: remctl <options> <host> <type> <service> <parameters>\n\
 Options:\n\
     -d            Debugging level of output\n\
     -h            Display this help\n\
-    -p <port>     remctld port (default: 4444)\n\
+    -p <port>     remctld port (default: 4373 falling back to 4444)\n\
     -s <service>  remctld service principal (default: host/<host>)\n\
     -v            Display the version of remctl\n";
 
@@ -114,7 +114,7 @@ main(int argc, char *argv[])
     char *server_host;
     struct addrinfo hints, *ai;
     char *service_name = NULL;
-    unsigned short port = 4444;
+    unsigned short port = 0;
     struct remctl *r;
     int errorcode = 0;
 
