@@ -1,4 +1,4 @@
-/*  $Id: config.c 3147 2007-03-25 04:41:09Z rra $
+/*  $Id: config.c 3294 2007-07-06 09:17:59Z rra $
 **
 **  Configuration parsing.
 **
@@ -340,12 +340,37 @@ server_config_load(const char *file)
 
     /* Read the configuration file. */
     config = xcalloc(1, sizeof(struct config));
-    if (read_conf_file(config, file) != 0)
-        warn("cannot read configuration file %s", file);
+    if (read_conf_file(config, file) != 0) {
+        free(config);
+        return NULL;
+    }
     return config;
 }
 
 
+/*
+**  Free the config structure created by calling server_config_load.
+*/
+void
+server_config_free(struct config *config)
+{
+    struct confline *rule;
+    size_t i;
+
+    for (i = 0; i < config->count; i++) {
+        rule = config->rules[i];
+        if (rule->logmask != NULL)
+            cvector_free(rule->logmask);
+        if (rule->acls != NULL)
+            free(rule->acls);
+        if (rule->line != NULL)
+            vector_free(rule->line);
+    }
+    free(config->rules);
+    free(config);
+}
+
+
 /*
 **  Given the confline corresponding to the command and the principal
 **  requesting access, see if the command is allowed.  Return true if so,
