@@ -1,4 +1,4 @@
-/*  $Id: generic.c 2978 2007-02-11 03:37:08Z rra $
+/*  $Id: generic.c 3380 2007-08-26 01:24:55Z rra $
 **
 **  Server implementation of generic protocol functions.
 **
@@ -44,8 +44,7 @@ server_new_client(int fd, gss_cred_id_t creds)
     OM_uint32 acc_minor;
     int flags, status;
     static const OM_uint32 req_gss_flags
-        = (GSS_C_MUTUAL_FLAG | GSS_C_REPLAY_FLAG | GSS_C_CONF_FLAG
-           | GSS_C_INTEG_FLAG);
+        = (GSS_C_MUTUAL_FLAG | GSS_C_CONF_FLAG | GSS_C_INTEG_FLAG);
 
     /* Create and initialize a new client struct. */
     client = xcalloc(1, sizeof(struct client));
@@ -164,9 +163,9 @@ server_new_client(int fd, gss_cred_id_t creds)
 
 fail:
     if (client->context != GSS_C_NO_CONTEXT)
-        gss_delete_sec_context(&minor, client->context, GSS_C_NO_BUFFER);
+        gss_delete_sec_context(&minor, &client->context, GSS_C_NO_BUFFER);
     if (name != GSS_C_NO_NAME)
-        gss_release_name(&minor, name);
+        gss_release_name(&minor, &name);
     if (client->ipaddress != NULL)
         free(client->ipaddress);
     if (client->hostname != NULL)
@@ -239,8 +238,16 @@ server_parse_command(struct client *client, const char *buffer, size_t length)
     vector_resize(argv, argc);
 
     /* Parse out the arguments and store them into a vector.  Arguments are
-       packed: (<arglength><argument>)+. */
+       packed: (<arglength><argument>)+.  Make sure each time through the loop
+       that they didn't send more arguments than they claimed to have. */
     while (p <= buffer + length - 4) {
+        if (argv->count >= argc) {
+            warn("sent more arguments than argc %lu", (unsigned long) argc);
+            server_send_error(client, ERROR_BAD_COMMAND,
+                              "Invalid command token");
+            vector_free(argv);
+            return NULL;
+        }
         memcpy(&tmp, p, 4);
         arglen = ntohl(tmp);
         p += 4;
