@@ -1,4 +1,4 @@
-/*  $Id: logging.c 2978 2007-02-11 03:37:08Z rra $
+/*  $Id: logging.c 3458 2007-08-30 02:20:28Z rra $
 **
 **  Logging and error handling for the remctld server.
 **
@@ -52,7 +52,7 @@ warn_token(const char *error, int status, OM_uint32 major, OM_uint32 minor)
         warn("error %s: invalid token format", error);
         break;
     case TOKEN_FAIL_LARGE:
-        warn("error %s: token too larger", error);
+        warn("error %s: token too large", error);
         break;
     case TOKEN_FAIL_EOF:
         warn("error %s: unexpected end of file", error);
