@@ -1,4 +1,4 @@
-/*  $Id: server-v1.c 2725 2006-08-22 23:19:12Z rra $
+/*  $Id: server-v1.c 2978 2007-02-11 03:37:08Z rra $
 **
 **  Protocol v1, server implementation.
 **
@@ -8,7 +8,7 @@
 **
 **  Written by Russ Allbery <rra@stanford.edu>
 **  Based on work by Anton Ushakov
-**  Copyright 2002, 2003, 2004, 2005, 2006
+**  Copyright 2002, 2003, 2004, 2005, 2006, 2007
 **      Board of Trustees, Leland Stanford Jr. University
 **
 **  See README for licensing terms.
@@ -16,15 +16,10 @@
 
 #include <config.h>
 #include <system.h>
+#include <portable/gssapi.h>
 
 #include <netinet/in.h>
 
-#ifdef HAVE_GSSAPI_H
-# include <gssapi.h>
-#else
-# include <gssapi/gssapi_generic.h>
-#endif
-
 #include <server/internal.h>
 #include <util/util.h>
 
@@ -84,18 +79,30 @@ server_v1_handle_commands(struct client *client, struct config *config)
 
     /* Receive the message. */
     status = token_recv_priv(client->fd, client->context, &flags, &token,
-                             MAX_TOKEN, &major, &minor);
+                             TOKEN_MAX_LENGTH, &major, &minor);
     if (status != TOKEN_OK) {
         warn_token("receiving command token", status, major, minor);
-        if (status != TOKEN_FAIL_EOF)
+        if (status == TOKEN_FAIL_LARGE)
+            server_send_error(client, ERROR_TOOMUCH_DATA, "Too much data");
+        else if (status != TOKEN_FAIL_EOF)
             server_send_error(client, ERROR_BAD_TOKEN, "Invalid token");
         return;
     }
 
+    /* Check the data size. */
+    if (token.length > TOKEN_MAX_DATA) {
+        warn("command data length %lu exceeds 64KB",
+             (unsigned long) token.length);
+        server_send_error(client, ERROR_TOOMUCH_DATA, "Too much data");
+        gss_release_buffer(&minor, &token);
+        return;
+    }
+
     /* Do the shared parsing of the message.  This code is identical to the
        code for v2 (v2 just pulls more data off the front of the token
        first). */
     argv = server_parse_command(client, token.value, token.length);
+    gss_release_buffer(&minor, &token);
     if (argv == NULL)
         return;
 
