@@ -1,4 +1,4 @@
-/*  $Id: system.h 2993 2007-03-03 07:23:20Z rra $
+/*  $Id: system.h 3591 2007-10-04 21:51:32Z rra $
 **
 **  Declarations of routines and variables in the C library.  Including this
 **  file is the equivalent of including all of the following headers,
@@ -83,6 +83,9 @@ extern int              snprintf(char *, size_t, const char *, ...)
 #if !HAVE_DECL_VSNPRINTF
 extern int              vsnprintf(char *, size_t, const char *, va_list);
 #endif
+#if !HAVE_DAEMON
+extern int              daemon(int, int);
+#endif
 #if !HAVE_SETENV
 extern int              setenv(const char *, const char *, int);
 #endif
@@ -113,4 +116,4 @@ END_DECLS
 # endif
 #endif
 
-#endif /* !CLIBRARY_H */
+#endif /* !SYSTEM_H */
