@@ -1,4 +1,4 @@
-/* $Id: api-t.c 2952 2007-02-04 04:31:45Z rra $ */
+/* $Id: api-t.c 3655 2007-11-09 08:20:55Z rra $ */
 /* Test suite for the high-level remctl library API. */
 
 /* Written by Russ Allbery <rra@stanford.edu>
@@ -33,6 +33,7 @@ do_tests(int n, const char *principal, int protocol)
     struct remctl_output *output;
     const char *test[] = { "test", "test", NULL };
     const char *error[] = { "test", "bad-command", NULL };
+    const char *no_service[] = { "all", NULL };
 
     /* Open the connection. */
     r = remctl_new();
@@ -105,6 +106,25 @@ do_tests(int n, const char *principal, int protocol)
             ok(n++, memcmp("Unknown command", output->data, 15) == 0);
         ok_int(n++, ERROR_UNKNOWN_COMMAND, output->error);
     }
+
+    /* Send a command with no service. */
+    ok(n++, remctl_command(r, no_service));
+    ok_string(n++, "No error", remctl_error(r));
+    output = remctl_output(r);
+    ok(n++, output != NULL);
+    ok_int(n++, REMCTL_OUT_OUTPUT, output->type);
+    ok_int(n++, 12, output->length);
+    if (output->data == NULL)
+        ok(n++, 0);
+    else
+        ok(n++, memcmp("hello world\n", output->data, 11) == 0);
+    ok_int(n++, 1, output->stream);
+    output = remctl_output(r);
+    ok(n++, output != NULL);
+    ok_int(n++, REMCTL_OUT_STATUS, output->type);
+    ok_int(n++, 0, output->status);
+
+    /* All done. */
     remctl_close(r);
     ok(n++, 1);
 
@@ -118,14 +138,15 @@ main(void)
     pid_t remctld;
     struct remctl_result *result;
     const char *test[] = { "test", "test", NULL };
+    const char *error[] = { "test", "bad-command", NULL };
     int n;
     struct timeval tv;
 
-    test_init(72);
+    test_init(98);
 
     principal = kerberos_setup();
     if (principal == NULL) {
-        skip_block(1, 72, "Kerberos tests not configured");
+        skip_block(1, 98, "Kerberos tests not configured");
     } else {
         remctld = spawn_remctld(principal);
         if (remctld <= 0)
@@ -141,12 +162,24 @@ main(void)
         result = remctl("localhost", 14444, principal, test);
         ok(n++, result != NULL);
         ok_int(n++, 0, result->status);
+        ok_int(n++, 0, result->stderr_len);
         ok_int(n++, 12, result->stdout_len);
         if (result->stdout_buf == NULL)
             ok(n++, 0);
         else
             ok(n++, memcmp("hello world\n", result->stdout_buf, 11) == 0);
         ok(n++, result->error == NULL);
+        remctl_result_free(result);
+        result = remctl("localhost", 14444, principal, error);
+        ok(n++, result != NULL);
+        ok_int(n++, 0, result->status);
+        ok_int(n++, 0, result->stdout_len);
+        ok_int(n++, 0, result->stderr_len);
+        if (result->error == NULL)
+            ok(n++, 0);
+        else
+            ok_string(n++, "Unknown command", result->error);
+        remctl_result_free(result);
 
         tv.tv_sec = 0;
         tv.tv_usec = 10000;
