@@ -1,4 +1,4 @@
-/*  $Id: libtest.c 3148 2007-03-25 23:24:30Z rra $
+/*  $Id: libtest.c 3235 2007-06-27 22:14:46Z rra $
 **
 **  Some utility routines for writing tests.
 **
@@ -218,7 +218,7 @@ char *
 kerberos_setup(void)
 {
     static const char format1[]
-        = "kinit -t -k data/test.keytab %s >/dev/null 2>&1 </dev/null";
+        = "kinit -k -t data/test.keytab %s >/dev/null 2>&1 </dev/null";
     static const char format2[]
         = "kinit -t data/test.keytab %s >/dev/null 2>&1 </dev/null";
     static const char format3[]
@@ -289,7 +289,7 @@ spawn_remctld(const char *principal)
     else if (child == 0) {
         execl("../server/remctld", "remctld", "-m", "-p", "14444", "-s",
               principal, "-P", "data/pid", "-f", "data/conf-simple", "-d",
-              "-S", (char *) 0);
+              "-S", "-F", (char *) 0);
         _exit(1);
     } else {
         alarm(1);
