@@ -1,4 +1,4 @@
-/*  $Id: runtests.c 2742 2006-09-08 04:02:06Z rra $
+/*  $Id: runtests.c 3521 2007-09-02 04:16:40Z rra $
 **
 **  Run a set of tests, reporting results.
 **
@@ -59,6 +59,11 @@
 /* sys/time.h must be included before sys/resource.h on some platforms. */
 #include <sys/resource.h>
 
+/* AIX doesn't have WCOREDUMP. */
+#ifndef WCOREDUMP
+# define WCOREDUMP(status)      ((unsigned)(status) & 0x80)
+#endif
+
 /* Test status codes. */
 enum test_status {
     TEST_FAIL,
