@@ -1,29 +1,13 @@
-/* $Id: gss-tokens-t.c 2678 2006-08-09 04:01:01Z rra $ */
+/* $Id: gss-tokens-t.c 2978 2007-02-11 03:37:08Z rra $ */
 /* gss-tokens test suite. */
 
 /* Written by Russ Allbery <rra@stanford.edu>
-   Copyright 2006 Board of Trustees, Leland Stanford Jr. University
+   Copyright 2006, 2007 Board of Trustees, Leland Stanford Jr. University
    See README for licensing terms. */
 
 #include <config.h>
 #include <system.h>
-
-#ifdef HAVE_GSSAPI_H
-# include <gssapi.h>
-#else
-# include <gssapi/gssapi_generic.h>
-#endif
-
-/* Handle compatibility to older versions of MIT Kerberos. */
-#ifndef HAVE_GSS_RFC_OIDS
-# define GSS_C_NT_USER_NAME gss_nt_user_name
-#endif
-
-/* Heimdal provides a nice #define for this. */
-#if !HAVE_DECL_GSS_KRB5_MECHANISM
-# include <gssapi/gssapi_krb5.h>
-# define GSS_KRB5_MECHANISM gss_mech_krb5
-#endif
+#include <portable/gssapi.h>
 
 #include <tests/libtest.h>
 #include <util/util.h>
